==> tencentcloud-sdk-java-3.0.93-sources.jar: com/tencentcloudapi/cms/v20190321/models/DeleteTextSampleRequest.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.cms.v20190321.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class DeleteTextSampleRequest  extends AbstractModel{

    /**
    * 唯一标识数组，目前暂时只支持单个删除
    */
    @SerializedName("Ids")
    @Expose
    private String [] Ids;

    /**
     * 获取唯一标识数组，目前暂时只支持单个删除
     * @return Ids 唯一标识数组，目前暂时只支持单个删除
     */
    public String [] getIds() {
        return this.Ids;
    }

    /**
     * 设置唯一标识数组，目前暂时只支持单个删除
     * @param Ids 唯一标识数组，目前暂时只支持单个删除
     */
    public void setIds(String [] Ids) {
        this.Ids = Ids;
    }

    /**
     * 内部实现，用户禁止调用
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamArraySimple(map, prefix + "Ids.", this.Ids);

    }
}

==> tencentcloud-sdk-java-3.1.268-sources.jar: com/tencentcloudapi/cms/v20190321/models/DeleteTextSampleRequest.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.cms.v20190321.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class DeleteTextSampleRequest extends AbstractModel{

    /**
    * 唯一标识数组，目前暂时只支持单个删除
    */
    @SerializedName("Ids")
    @Expose
    private String [] Ids;

    /**
     * Get 唯一标识数组，目前暂时只支持单个删除 
     * @return Ids 唯一标识数组，目前暂时只支持单个删除
     */
    public String [] getIds() {
        return this.Ids;
    }

    /**
     * Set 唯一标识数组，目前暂时只支持单个删除
     * @param Ids 唯一标识数组，目前暂时只支持单个删除
     */
    public void setIds(String [] Ids) {
        this.Ids = Ids;
    }

    public DeleteTextSampleRequest() {
    }

    /**
     * NOTE: Any ambiguous key set via .set("AnyKey", "value") will be a shallow copy,
     *       and any explicit key, i.e Foo, set via .setFoo("value") will be a deep copy.
     */
    public DeleteTextSampleRequest(DeleteTextSampleRequest source) {
        if (source.Ids != null) {
            this.Ids = new String[source.Ids.length];
            for (int i = 0; i < source.Ids.length; i++) {
                this.Ids[i] = new String(source.Ids[i]);
            }
        }
    }


    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamArraySimple(map, prefix + "Ids.", this.Ids);

    }
}
